
**********************Conway & Gawronski (2013) Process Dissociation Analysis of Moral Dilemma Judgments SPSS Syntax********************************


*Citation: Conway, P., & Gawronski, B. (2013). Deontological and utilitarian inclinations in moral decision-making: A process dissociation approach. Journal of Personality and Social Psychology, 104, 216-235. doi:10.1037/a0031021 
*Stimuli: 10 Moral Dilemmas, each with two versions: congruent and incongruent 
*Incongruent dilemmas correspond to traditional high-conflict moral dilemmas (see Koenigs et al., 2007), pitting deontology against utilitarianism. 
*Congruent dilemmas are identically worded except for the benefits of harmful action in each dilemma, such that deontology and utilitarianism are no longer in conflict.  
*Recommended Dilemma Response Options: "Yes, I find this appropriate" or "No, I find this inappropriate" for each dilemma 


***Guide to Variable Names***
*Note: Variable names correspond to the variable names employed by Conway & Gawronski's medialab version of the dilemma battery.
*Note that the dilemma numbers also correspond to Appendix A in Conway & Gawronski, 2013, as well as to the dilemma numbers in Conway & Gawronski's Recommended Running Procedures document. 
*Hence, Dilemma 01 = Time Machine (Incongruent), Dilemma 02 = Time Machine (incongruent), Dilemma 03 = Car accident (Incongruent), etc. 

*D01IQ = Dilemma 01, Incongruent Question 
*D02CQ = Dilemma 01, Congruent Question 
*D03IQ = Dilemma 03, Incongruent Question
*D04CQ = Dilemma 04, Congruent Question, etc...

*perc_act_inc = Percentage of harmful action accepted for incongruent dilemmas (analogous to raw utilitarian judgments using traditional analysis) 
*perc_act_con = Percentage of harmful action accepted for congruent dilemmas 
*perc_inac_inc = Percentage of harmful action rejected for incongruent dilemmas (analogous to raw deontological judgments using traditional analysis) 
*perc_inac_con = Percentage of harmful action rejected for congruent dilemmas

*PD_utilitarian = Utilitarian Parameter 
*PD_deontological = Deontology Parameter
*zPD_utilitarian = Standardized Utilitarian Parameter 
*zPD_deontological = Standardized Deontology Parameter

*Condition = code for which condition participants were in (e.g., 1 = cognitive load, 2 = control) 
*Score = name for the within-subjects variable created during repeated measures analysis. There are two levels of this variable: one for PD_utilitarian and one for PD_deontological scores. 

*D01IH = Dilemma 01, Incongruent Hardness (i.e., dilemma difficulty), etc...  
*Dilemma difficulty ratings are OPTIONAL manipulation checks to examine whether participants perceive incongruent dilemmas as more difficult than congruent ones, on average.  
*Difficulty_Incongruent = Mean dilemma difficulty rating across incongruent dilemmas 
*Difficulty_Congruent = Mean dilemma difficulty rating across congruent dilemmas 


***********************************************Process Dissociation Parameter Calculation, Multiple Steps****************************************

***Step 1: Dilemma Response Recoding (IF NECESARY)***
*In order for the analyses below to work correctly, it is necessary that all responses of "No, I find this inappropriate" = 0 and "Yes, I find this appropriate" = 1 for all dilemmas. 
*Depending on how you coded dilemma responses, you MAY need to recode. 
*If you used the medialab file provided by Conway & Gawronski, you will need to recode in the following manner: 

RECODE
  D01IQ D02CQ D03IQ D04CQ D05IQ D06CQ D07IQ D08CQ D09IQ D10CQ D11IQ D12CQ
  D13IQ D14CQ D15IQ D16CQ D17IQ D18CQ D19IQ D20CQ  (1=0)  (2=1).
EXECUTE. 

***Step 2: Initial Calculations***
*Note that correctly calculating the parameters requires NO MISSING DATA for dilemma responses. If a participant answered fewer than all 20 dilemmas, they must be excluded. 
*Note that occasionally there may be an error at this stage if someone's PD_utilitarian score is zero, as this would require division by zero. If this occurs, please exclude the participant with a PD_utilitarian score of 0. 

COMPUTE perc_act_inc = MEAN(D01IQ, D03IQ, D05IQ, D07IQ, D09IQ, D11IQ, D13IQ, D15IQ, D17IQ, D19IQ).
COMPUTE perc_act_con = MEAN(D02CQ, D04CQ, D06CQ, D08CQ, D10CQ, D12CQ, D14CQ, D16CQ, D18CQ, D20CQ).
COMPUTE perc_inac_inc = 1 - perc_act_inc.
COMPUTE perc_inac_con = 1 - perc_act_con.
COMPUTE PD_utilitarian = perc_inac_con - perc_inac_inc.
COMPUTE PD_deontological = perc_inac_inc / (1 - PD_utilitarian).
EXECUTE.

****Step 3: Exclusion (Optional)***
*If you decide to exclude any participants (e.g., for failing a manipulation check) then you must re-standardize the parameters before analysis. No other recalculations are necessary. 

***Step 4: Standardizing PD Parameters***
*In order to compare parameters across conditions, it is necessary to standardize them as they are on different metrics (see Appendix B in Conway & Gawronski, 2013, p. 235) 

DESCRIPTIVES VARIABLES=PD_utilitarian PD_deontological
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.


********************************Analyses, Process Dissociation Parameters and Traditional Raw Dilemma Judgments****************************************

***Example PD Analysis: Comparing Standardized PD Parameters Across Conditions***
*Note that repeated measures is appropriate as each participant provides both a Deontology and Utilitarianism score. 

GLM zPD_deontological zPD_utilitarian BY Condition
  /WSFACTOR=score 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(Condition*score)
  /EMMEANS=TABLES(Condition*score) 
  /PRINT=DESCRIPTIVE ETASQ HOMOGENEITY 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=score 
  /DESIGN=Condition.


***Example Traditional Analysis: Comparing Raw "Utilitarian" Judgments Across Conditions***
*Note that the exact same analysis could be done for Raw "Deontological" Judgments and it will be the exact same result with the opposite signage (i.e., a negative t-test instead of positive one)

T-TEST GROUPS=Condition(1 2)
  /MISSING=ANALYSIS
  /VARIABLES=perc_act_inc
  /CRITERIA=CI(.95).


***Example Correlational Analysis***
*You should expect that the utilitarian parameter correlates positively with accepting action in incongruent dilemmas (per_act_inc).
*You should expect that the deontology parameter correlates negatively with accepting action in incongruent dilemmas (per_act_inc).
*Typically the deontology and utilitarian parameters are either uncorrelated or mildly positively correlated.

CORRELATIONS
  /VARIABLES=perc_act_inc PD_utilitarian PD_deontological
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.


***Example Regression Analysis***

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT DependentVariable1
  /METHOD=ENTER zPD_utilitarian zPD_deontological.


***Example Optional Manipulation Check: Dilemma Difficulty***
*You can use this analysis to determine whether participants rated incongruent dilemmas as more difficult than congruent ones (replicating Conway & Gawronski, 2013).

COMPUTE Difficulty_Incongruent = MEAN(D01IH, D03IH, D05IH, D07IH, D09IH, D11IH, D13IH, D15IH, D17IH, D19IH).
COMPUTE Difficulty_Congruent = MEAN(D02CH, D04CH, D06CH, D08CH, D10CH, D12CH, D14CH, D16CH, D18CH, D20CH).
EXECUTE.

T-TEST PAIRS=Difficulty_Incongruent WITH Difficulty_Congruent (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


